@@ -1,7 +1,5 @@
 """
-Type annotations for ssm service client waiters.
-
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm/waiters.html)
+Main interface for ssm service client waiters.
 
 Usage::
 
@@ -27,7 +25,7 @@ __all__ = ("CommandExecutedWaiter",)
 
 class CommandExecutedWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/ssm.html#SSM.Waiter.command_executed)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm/waiters.html#commandexecutedwaiter)
+    [Waiter.CommandExecuted documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/ssm.html#SSM.Waiter.CommandExecuted)
     """
 
     def wait(
@@ -38,6 +36,5 @@ class CommandExecutedWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/ssm.html#SSM.Waiter.CommandExecutedWaiter)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm/waiters.html#commandexecuted)
+        [CommandExecuted.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/ssm.html#SSM.Waiter.CommandExecuted.wait)
         """
